@@ -3,7 +3,7 @@
   mating.c: functions to create mating tables
   Copyright 2009 Joel J. Adamson 
 
-  $Id: mating.c 1021 2010-04-25 13:17:38Z joel $
+  $Id: mating.c 1045 2010-05-07 19:20:42Z trashbird1240 $
 
   Joel J. Adamson	-- http://www.unc.edu/~adamsonj
   University of North Carolina at Chapel Hill
@@ -28,7 +28,9 @@
 
 */
 
-#include "haploidpriv.h"
+#include <stdlib.h>
+#include <error.h>
+#include <errno.h>
 
 double **
 rmtable (size_t geno, double * freq)
